@@ -7,7 +7,7 @@ class JsonResponse(MWRAPResponse):
     
 
     @property 
-    def data(self):
+    def data(self) -> object:
         """
         Returns the json data of the response as a dictionary
 
@@ -33,4 +33,5 @@ class JsonResponse(MWRAPResponse):
         self._data = self.response.json()
 
     def __str__(self):
-        return "<JsonResponse, Status Code: {}, Data: {}>".format(self.response.status_code, str(self._data))
\ No newline at end of file
+        return "<JsonResponse, Status Code: {}, Data: {}>".format(self.response.status_code, str(self._data))
+        
\ No newline at end of file
