@@ -47,6 +47,12 @@ class TestInvoice(IntegrationTest):
 
             assert isinstance(inv_getlist, ListingResponse)
 
+            assert inv_getlist.current_page == 1
+            assert inv_getlist.is_last is not None
+            assert inv_getlist.next_page is not None
+            assert inv_getlist.total is not None
+            assert inv_getlist.page_size is not None
+
     def test_locked(self):
         with self.recorder.use_cassette("TestInvoice.test_locked"):
             inv_locked = self.moco.Invoice.locked()
@@ -54,6 +60,12 @@ class TestInvoice(IntegrationTest):
             assert inv_locked.response.status_code == 200
             
             assert isinstance(inv_locked, ListingResponse)
+                        
+            assert inv_locked.current_page == 1
+            assert inv_locked.is_last is not None
+            assert inv_locked.next_page is not None
+            assert inv_locked.total is not None
+            assert inv_locked.page_size is not None
 
     def test_get(self):
         customer = self.get_customer()
@@ -145,47 +157,6 @@ class TestInvoice(IntegrationTest):
             assert isinstance(inv_create, JsonResponse)
             assert isinstance(inv_pdf, FileResponse)
 
-    def test_timesheet_no_hours(self):
-        customer = self.get_customer()
-        
-        with self.recorder.use_cassette("TestInvoice.test_timesheet_no_hours"):
-            recipient_address = "Mein Kunde\nHauptstrasse 1\n8000 Zürich"
-            creation_date = date(2018, 9, 17)
-            due_date = date(2018, 10, 16)
-            title = "invoice"
-            tax = 8.0
-            currency = "EUR"
-            service_from_date = date(2019, 12, 1)
-            service_to_date = date(2019, 12, 31)
-
-            item_generator = InvoiceItemGenerator()
-            items = [
-                item_generator.generate_title("Hours"),
-                item_generator.generate_description("Listing of all hours"),
-                item_generator.generate_item("Service", quantity=2, unit="hours", unit_price=65, net_total=130)
-            ]
-
-            inv_create = self.moco.Invoice.create(
-                customer.id,
-                recipient_address, 
-                creation_date, 
-                due_date, 
-                service_from_date, 
-                service_to_date, 
-                title, 
-                tax, 
-                currency,
-                items
-            )
-
-            inv_time = self.moco.Invoice.timesheet(inv_create.data.id)
-            
-            assert inv_create.response.status_code == 200
-            assert inv_time.response.status_code == 404
-
-            assert isinstance(inv_create, JsonResponse)
-            assert isinstance(inv_time, ErrorResponse)
-
     def test_update_status(self):
         customer = self.get_customer()
 
@@ -390,4 +361,4 @@ class TestInvoice(IntegrationTest):
             assert inv_create.data.footer == footer
             assert inv_create.data.cash_discount == cash_discount
             assert inv_create.data.cash_discount_days == cash_discount_days
-            
+            
\ No newline at end of file
